from . import biobb_pdb_fetch
from . import biobb_pdb_reres
from . import biobb_pdb_chain
from . import biobb_pdb_chainxseg
from . import biobb_pdb_delhetatm
from . import biobb_pdb_merge
from . import biobb_pdb_mkensemble
from . import biobb_pdb_seg
from . import biobb_pdb_splitmodel
from . import biobb_pdb_splitseg
from . import biobb_pdb_tidy
from . import biobb_pdb_uniqname

name = "pdb_tools"
__all__ = ["biobb_pdb_fetch", "biobb_pdb_reres", "biobb_pdb_chain", "biobb_pdb_chainxseg", "biobb_pdb_delhetatm", "biobb_pdb_merge", "biobb_pdb_mkensemble", "biobb_pdb_seg", "biobb_pdb_splitmodel", "biobb_pdb_splitseg", "biobb_pdb_tidy", "biobb_pdb_uniqname"]



#!/usr/bin/env python3

"""Module containing the Mkensemble class and the command line interface."""

import argparse
import os
import zipfile
from pathlib import Path
from typing import Optional

from biobb_common.configuration import settings
from biobb_common.generic.biobb_object import BiobbObject
from biobb_common.tools import file_utils as fu
from biobb_common.tools.file_utils import launchlogger


class Mkensemble(BiobbObject):
    """
    | biobb_pdb_tools Mkensemble
    | Merges several PDB files into one multi-model (ensemble) file.
    | This tool merges several PDB files into one multi-model (ensemble) file. It can be used to merge several PDB files into one multi-model (ensemble) file.

    Args:
        input_file_path (str): ZIP file of selected proteins. File type: input. `Sample file <https://raw.githubusercontent.com/bioexcel/biobb_pdb_tools/master/biobb_pdb_tools/test/data/pdb_tools/input_pdb_mkensemble1.pdb>`_. Accepted formats: zip (edam:format_3987).
        output_file_path (str): Multi-model (ensemble) PDB file with input PDBs merged. File type: output. `Sample file <https://raw.githubusercontent.com/bioexcel/biobb_pdb_tools/master/biobb_pdb_tools/test/reference/pdb_tools/ref_pdb_mkensemble.pdb>`_. Accepted formats: pdb (edam:format_3987).
        properties (dic):
            * **binary_path** (*str*) - ("pdb_mkensemble") Path to the pdb_mkensemble executable binary.
            * **remove_tmp** (*bool*) - (True) [WF property] Remove temporal files.
            * **restart** (*bool*) - (False) [WF property] Do not execute if output files exist.

    Examples:
        This is a use example of how to use the building block from Python::

            from biobb_pdb_tools.pdb_tools.biobb_pdb_mkensemble import biobb_pdb_mkensemble

            biobb_pdb_mkensemble(input_file_path='/path/to/input1.zip',
                    output_file_path='/path/to/output.pdb')

    Info:
        * wrapped_software:
            * name: pdb_tools
            * version: >=2.5.0
            * license: Apache-2.0
        * ontology:
            * name: EDAM
            * schema: http://edamontology.org/EDAM.owl

    """

    def __init__(
        self, input_file_path, output_file_path, properties=None, **kwargs
    ) -> None:
        properties = properties or {}

        super().__init__(properties)
        self.locals_var_dict = locals().copy()
        self.io_dict = {
            "in": {"input_file_path": input_file_path},
            "out": {"output_file_path": output_file_path},
        }

        self.binary_path = properties.get("binary_path", "pdb_mkensemble")
        self.properties = properties

        self.check_properties(properties)
        self.check_arguments()

    @launchlogger
    def launch(self) -> int:
        """Execute the :class:`Mkensemble <biobb_pdb_tools.pdb_tools.pdb_mkensemble>` object."""

        if self.check_restart():
            return 0
        self.stage_files()

        input_file_path = self.stage_io_dict["in"]["input_file_path"]
        folder_path = os.path.dirname(input_file_path)

        if zipfile.is_zipfile(input_file_path):
            with zipfile.ZipFile(input_file_path, "r") as zip_ref:
                zip_ref.extractall(folder_path)

            pdb_files = [
                file
                for file in os.listdir(folder_path)
                if file.lower().endswith(".pdb")
            ]

            input_file_list = [os.path.join(folder_path, file) for file in pdb_files]

            input_file_list = [Path(i) for i in input_file_list]
            input_file_list = sorted(input_file_list, key=lambda i: i.stem.upper())
            input_file_list = [str(i) for i in input_file_list]

            self.cmd = [
                self.binary_path,
                *input_file_list,
                ">",
                self.io_dict["out"]["output_file_path"],
            ]

        else:
            fu.log(
                f"The archive {input_file_path} is not a ZIP!",
                self.out_log,
                self.global_log,
            )

        fu.log(" ".join(self.cmd), self.out_log, self.global_log)

        fu.log(
            "Creating command line with instructions and required arguments",
            self.out_log,
            self.global_log,
        )

        self.run_biobb()
        self.copy_to_host()

        self.tmp_files.extend([self.stage_io_dict.get("unique_dir", "")])

        self.remove_tmp_files()
        self.check_arguments(output_files_created=True, raise_exception=False)

        return self.return_code


def biobb_pdb_mkensemble(
    input_file_path: str,
    output_file_path: str,
    properties: Optional[dict] = None,
    **kwargs,
) -> int:
    """Create :class:`Mkensemble <biobb_pdb_tools.pdb_tools.pdb_mkensemble>` class and
    execute the :meth:`launch() <biobb_pdb_tools.pdb_tools.pdb_mkensemble.launch>` method."""
    return Mkensemble(
        input_file_path=input_file_path,
        output_file_path=output_file_path,
        properties=properties,
        **kwargs,
    ).launch()


def main():
    """Command line execution of this building block. Please check the command line documentation."""
    parser = argparse.ArgumentParser(
        description="Merges several PDB files into one multi-model (ensemble) file.",
        formatter_class=lambda prog: argparse.RawTextHelpFormatter(prog, width=99999),
    )
    parser.add_argument("--config", required=True, help="Configuration file")
    required_args = parser.add_argument_group("required arguments")
    required_args.add_argument(
        "--input_file_path",
        required=True,
        help="Description for the first input file path. Accepted formats: pdb.",
    )
    required_args.add_argument(
        "--output_file_path",
        required=True,
        help="Description for the output file path. Accepted formats: zip.",
    )

    args = parser.parse_args()
    args.config = args.config or "{}"
    properties = settings.ConfReader(config=args.config).get_prop_dic()

    biobb_pdb_mkensemble(
        input_file_path=args.input_file_path,
        output_file_path=args.output_file_path,
        properties=properties,
    )


if __name__ == "__main__":
    main()



#!/usr/bin/env python3

"""Module containing the Pdbtofasta class and the command line interface."""

import argparse
from typing import Optional

from biobb_common.configuration import settings
from biobb_common.generic.biobb_object import BiobbObject
from biobb_common.tools import file_utils as fu
from biobb_common.tools.file_utils import launchlogger


class Pdbtofasta(BiobbObject):
    """
    | biobb_pdb_tofasta Pdbtofasta
    | Extracts the residue sequence in a PDB file to FASTA format.
    | This tool extracts the residue sequence in a PDB file to FASTA format. It can be used to extract the sequence of a PDB file to FASTA format.

    Args:
        input_file_path (str): PDB file. File type: input. `Sample file <https://raw.githubusercontent.com/bioexcel/biobb_pdb_tools/master/biobb_pdb_tools/test/data/pdb_tools/input_pdb_tofasta.pdb>`_. Accepted formats: pdb (edam:format_1476).
        output_file_path (str): FASTA file containing the aminoacids sequence. File type: output. `Sample file <https://raw.githubusercontent.com/bioexcel/biobb_pdb_tools/master/biobb_pdb_tools/test/reference/pdb_tools/ref_pdb_tofasta.pdb>`_. Accepted formats: fasta (edam:format_1929), fa (edam:format_1929).
        properties (dic):
            * **multi** (*bool*) - (True) Splits the different chains into different records in the FASTA file.
            * **binary_path** (*str*) - ("pdb_tofasta") Path to the pdb_tofasta executable binary.
            * **remove_tmp** (*bool*) - (True) [WF property] Remove temporal files.
            * **restart** (*bool*) - (False) [WF property] Do not execute if output files exist.

    Examples:
        This is a use example of how to use the building block from Python::

            from biobb_pdb_tools.pdb_tools.biobb_pdb_tofasta import biobb_pdb_tofasta

            prop = {
                'multi': True
            }
            biobb_pdb_tofasta(input_file_path='/path/to/input.pdb',
                    output_file_path='/path/to/output.fasta',
                    properties=prop)

    Info:
        * wrapped_software:
            * name: pdb_tools
            * version: >=2.5.0
            * license: Apache-2.0
        * ontology:
            * name: EDAM
            * schema: http://edamontology.org/EDAM.owl

    """

    def __init__(
        self, input_file_path, output_file_path, properties=None, **kwargs
    ) -> None:
        properties = properties or {}

        super().__init__(properties)
        self.locals_var_dict = locals().copy()

        self.io_dict = {
            "in": {"input_file_path": input_file_path},
            "out": {"output_file_path": output_file_path},
        }

        self.binary_path = properties.get("binary_path", "pdb_tofasta")
        self.multi = properties.get("multi", True)
        self.properties = properties

        self.check_properties(properties)
        self.check_arguments()

    @launchlogger
    def launch(self) -> int:
        """Execute the :class:`Pdbtofasta <biobb_pdb_tools.pdb_tools.pdb_tofasta>` object."""

        if self.check_restart():
            return 0
        self.stage_files()

        instructions = []
        if self.multi:
            instructions.append("-multi")
            fu.log("Appending optional boolean property", self.out_log, self.global_log)

        self.cmd = [
            self.binary_path,
            " ".join(instructions),
            self.stage_io_dict["in"]["input_file_path"],
            ">",
            self.io_dict["out"]["output_file_path"],
        ]

        fu.log(" ".join(self.cmd), self.out_log, self.global_log)

        fu.log(
            "Creating command line with instructions and required arguments",
            self.out_log,
            self.global_log,
        )

        self.run_biobb()
        self.copy_to_host()

        if unique_dir := self.stage_io_dict.get("unique_dir", ""):
            self.tmp_files.extend([unique_dir])
        self.remove_tmp_files()
        self.check_arguments(output_files_created=True, raise_exception=False)

        return self.return_code


def biobb_pdb_tofasta(
    input_file_path: str,
    output_file_path: str,
    properties: Optional[dict] = None,
    **kwargs,
) -> int:
    """Create :class:`Pdbtofasta <biobb_pdb_tools.pdb_tools.pdb_tofasta>` class and
    execute the :meth:`launch() <biobb_pdb_tools.pdb_tools.pdb_tofasta.launch>` method."""

    return Pdbtofasta(
        input_file_path=input_file_path,
        output_file_path=output_file_path,
        properties=properties,
        **kwargs,
    ).launch()


def main():
    """Command line execution of this building block. Please check the command line documentation."""
    parser = argparse.ArgumentParser(
        description="Extracts the residue sequence in a PDB file to FASTA format.",
        formatter_class=lambda prog: argparse.RawTextHelpFormatter(prog, width=99999),
    )
    parser.add_argument("--config", required=True, help="Configuration file")

    required_args = parser.add_argument_group("required arguments")
    required_args.add_argument(
        "--input_file_path",
        required=True,
        help="Description for the first input file path. Accepted formats: pdb.",
    )
    required_args.add_argument(
        "--output_file_path",
        required=True,
        help="Description for the output file path. Accepted formats: fasta.",
    )

    args = parser.parse_args()
    args.config = args.config or "{}"
    properties = settings.ConfReader(config=args.config).get_prop_dic()

    biobb_pdb_tofasta(
        input_file_path=args.input_file_path,
        output_file_path=args.output_file_path,
        properties=properties,
    )


if __name__ == "__main__":
    main()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="biobb_pdb_tools",
    version="5.0.0",
    author="Biobb developers",
    author_email="agustin.garcia@irbbarcelona.org",
    description="Biobb_pdb_tools is a swiss army knife for manipulating and editing PDB files.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    keywords="Bioinformatics Workflows BioExcel Compatibility",
    url="https://github.com/bioexcel/biobb_pdb_tools",
    project_urls={
        "Documentation": "http://biobb-pdb-tools.readthedocs.io/en/latest/",
        "Bioexcel": "https://bioexcel.eu/",
    },
    packages=setuptools.find_packages(exclude=["docs", "test"]),
    package_data={"biobb_pdb_tools": ["py.typed"]},
    install_requires=["biobb_common==5.0.0"],
    python_requires=">=3.9",
    entry_points={
        "console_scripts": [
            "biobb_pdb_chain = biobb_pdb_tools.pdb_tools.biobb_pdb_chain:main",
            "biobb_pdb_chainxseg = biobb_pdb_tools.pdb_tools.biobb_pdb_chainxseg:main",
            "biobb_pdb_delhetatm = biobb_pdb_tools.pdb_tools.biobb_pdb_delhetatm:main",
            "biobb_pdb_fetch = biobb_pdb_tools.pdb_tools.biobb_pdb_fetch:main",
            "biobb_pdb_merge = biobb_pdb_tools.pdb_tools.biobb_pdb_merge:main",
            "biobb_pdb_mkensemble = biobb_pdb_tools.pdb_tools.biobb_pdb_mkensemble:main",
            "biobb_pdb_reres = biobb_pdb_tools.pdb_tools.biobb_pdb_reres:main",
            "biobb_pdb_seg = biobb_pdb_tools.pdb_tools.biobb_pdb_seg:main",
            "biobb_pdb_splitmodel = biobb_pdb_tools.pdb_tools.biobb_pdb_splitmodel:main",
            "biobb_pdb_splitseg = biobb_pdb_tools.pdb_tools.biobb_pdb_splitseg:main",
            "biobb_pdb_tidy = biobb_pdb_tools.pdb_tools.biobb_pdb_tidy:main",
            "biobb_pdb_tofasta = biobb_pdb_tools.pdb_tools.biobb_pdb_tofasta:main",
            "biobb_pdb_uniqname = biobb_pdb_tools.pdb_tools.biobb_pdb_uniqname:main",
        ]
    },
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Programming Language :: Python :: 3.9",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: POSIX",
        "Operating System :: Unix",
    ],
)
